@@ -42,7 +42,7 @@ make_envelope_object <- function(type, curve_set, LB, UB, T_0,
     df <- data.frame(curve_set_rdf(curve_set), central=T_0, lo=LB, hi=UB)
   }
   if(isenvelope) {
-    res <- spatstat.core::fv(x=df, argu = picked_attr[['argu']],
+    res <- spatstat.explore::fv(x=df, argu = picked_attr[['argu']],
                         ylab = picked_attr[['ylab']], valu = "central", fmla = ". ~ r",
                         alim = c(min(curve_set[['r']]), max(curve_set[['r']])),
                         labl = picked_attr[['labl']], desc = picked_attr[['desc']],
@@ -184,8 +184,8 @@ individual_central_region <- function(curve_set, type = "erl", coverage = 0.50,
 
   switch(alternative,
          "two.sided" = {},
-         "less" = { UB <- Inf },
-         "greater" = { LB <- -Inf })
+         "less" = { for(ai in 1:length(alpha)) UBounds[[ai]] <- Inf },
+         "greater" = { for(ai in 1:length(alpha)) LBounds[[ai]] <- -Inf })
 
   if(length(alpha) > 1) { # Multiple envelopes
     names(LBounds) <- names(UBounds) <- paste0(100*coverage)
@@ -458,7 +458,7 @@ print.combined_global_envelope <- function(x, ...) {
 #' @export
 #' @seealso \code{\link{central_region}}, \code{\link{global_envelope_test}}
 #' @examples
-#' if(require("spatstat.core", quietly=TRUE)) {
+#' if(require("spatstat.explore", quietly=TRUE)) {
 #'   X <- unmark(spruces)
 #'   \donttest{nsim <- 1999 # Number of simulations}
 #'   \dontshow{nsim <- 19 # Number of simulations}
@@ -781,7 +781,7 @@ central_region <- function(curve_sets, type = "erl", coverage = 0.50,
                            probs = c(0.25, 0.75),
                            quantile.type = 7,
                            central = "median", nstep = 2, ...) {
-  if(length(class(curve_sets)) == 1 && inherits(curve_sets, "list")) {
+  if(!is_a_single_curveset(curve_sets)) {
     if(length(curve_sets) > 1) { # Combined test
       if(!(nstep %in% c(1,2))) stop("Invalid number of steps (nstep) for combining. Should be 1 or 2.")
       if(nstep == 2) # Two-step combining procedure
@@ -984,7 +984,7 @@ central_region <- function(curve_sets, type = "erl", coverage = 0.50,
 #' \code{\link{GET.composite}}
 #' @examples
 #' # Goodness-of-fit testing for simple hypothesis
-#' if(require("spatstat.core", quietly=TRUE)) {
+#' if(require("spatstat.explore", quietly=TRUE)) {
 #'   # Testing complete spatial randomness (CSR)
 #'   #==========================================
 #'   X <- unmark(spruces)
@@ -1109,7 +1109,7 @@ global_envelope_test <- function(curve_sets, type = "erl", alpha = 0.05,
                           alternative = c("two.sided", "less", "greater"),
                           ties = "erl", probs = c(0.025, 0.975), quantile.type = 7,
                           central = "mean", nstep = 2, ...) {
-  if(length(class(curve_sets)) == 1 && inherits(curve_sets, "list")) {
+  if(!is_a_single_curveset(curve_sets)) {
     if(length(curve_sets) > 1) { # Combined test
       if(!(nstep %in% c(1,2))) stop("Invalid number of steps (nstep) for combining. Should be 1 or 2.")
       if(nstep == 2) # Two-step combining procedure
@@ -1192,7 +1192,7 @@ global_envelope_test <- function(curve_sets, type = "erl", alpha = 0.05,
 #'
 #' ## Testing complete spatial randomness (CSR)
 #' #-------------------------------------------
-#' if(require("spatstat.core", quietly=TRUE)) {
+#' if(require("spatstat.explore", quietly=TRUE)) {
 #'   X <- unmark(spruces)
 #'   \donttest{nsim <- 2499 # Number of simulations}
 #'   \dontshow{nsim <- 19 # Number of simulations for testing}
@@ -1244,7 +1244,7 @@ rank_envelope <- function(curve_set, type = "rank", ...) {
 #' # See more examples in ?global_envelope_test
 #' ## Testing complete spatial randomness (CSR)
 #' #-------------------------------------------
-#' if(require("spatstat.core", quietly=TRUE)) {
+#' if(require("spatstat.explore", quietly=TRUE)) {
 #'   X <- spruces
 #'   \donttest{nsim <- 999 # Number of simulations}
 #'   \dontshow{nsim <- 19 # Number of simulations for testing}
